@@ -1,7 +1,7 @@
 import logbook
 
 import attr
-from regipy.exceptions import RegistryKeyNotFoundException, NoRegistryValuesException
+from regipy.exceptions import RegistryKeyNotFoundException, NoRegistryValuesException, RegistryParsingException
 from regipy.hive_types import SYSTEM_HIVE_TYPE
 from regipy.plugins.plugin import Plugin
 from regipy.utils import convert_wintime
@@ -26,20 +26,33 @@ class ServicesPlugin(Plugin):
                 logger.error(ex)
                 continue
             self.entries[control_set_services_path] = {
-                'timestamp': convert_wintime(subkey.header.last_modified, as_json=self.as_json)        
+                'timestamp': convert_wintime(subkey.header.last_modified, as_json=self.as_json)
             }
             services = []
             for service in subkey.iter_subkeys():
                 values = None
+                parameters = []
                 if service.values_count > 0:
-                    values = [attr.asdict(x) for x in service.iter_values(as_json=True)]
+                    try:
+                        values = [attr.asdict(x) for x in service.iter_values(as_json=True)]
+                    except RegistryParsingException as ex:
+                        logger.info(f'Exception while parsing data for service {service.name}: {ex}')
+
+                    if service.subkey_count:
+                        try:
+                            service_parameters_path = r'{}\{}'.format(control_set_services_path, service.name)
+                            for parameter in self.registry_hive.recurse_subkeys(nk_record=service,
+                                                                                path=service_parameters_path,
+                                                                                as_json=True):
+                                parameters.append(attr.asdict(parameter))
+                        except RegistryParsingException as ex:
+                            logger.info(f'Exception while parsing parameters for service {service.name}: {ex}')
+
                 entry = {
                     'name': service.name,
                     'last_modified': convert_wintime(service.header.last_modified, as_json=self.as_json),
                     'values': values,
-                    'parameters': [attr.asdict(x) for x in self.registry_hive.recurse_subkeys(nk_record=service, path=r'{}\{}'.format(
-                        control_set_services_path, service.name), as_json=True)] if service.subkey_count else None
+                    'parameters': parameters
                 }
                 services.append(entry)
             self.entries[control_set_services_path]['services'] = services
-
